<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>Backend</name>
    <message>
        <location filename="../TarBackend.cpp" line="249"/>
        <source>Could not read archive</source>
        <translation>Não foi possível ler arquivo</translation>
    </message>
    <message>
        <location filename="../TarBackend.cpp" line="251"/>
        <source>Archive Loaded</source>
        <translation>Arquivo carregado</translation>
    </message>
    <message>
        <location filename="../TarBackend.cpp" line="284"/>
        <source>Extraction Finished</source>
        <translation>Extração finalizada</translation>
    </message>
    <message>
        <location filename="../TarBackend.cpp" line="286"/>
        <source>Modification Finished</source>
        <translation>Modificação finalizada</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="35"/>
        <source>Archive:</source>
        <translation>Arquivo:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="69"/>
        <location filename="../MainUI.cpp" line="331"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="125"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="134"/>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="145"/>
        <source>&amp;Burn to Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="178"/>
        <source>&amp;Open Archive</source>
        <translation>&amp;Abrir arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="181"/>
        <source>Open archive</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="186"/>
        <source>&amp;New Archive</source>
        <translation>&amp;Novo arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="189"/>
        <source>New archive</source>
        <translation>Novo arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="194"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="199"/>
        <source>Add File(s)</source>
        <translation>Adicionar arquivo(s)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="202"/>
        <source>Add files to archive</source>
        <translation>Adicionar para o arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="207"/>
        <source>Remove File(s)</source>
        <translation>Remover arquivo(s)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="210"/>
        <source>Remove selection from archive</source>
        <translation>Remover seleção do arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="215"/>
        <source>Extract All</source>
        <translation>Extrair tudo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Extract archive into a directory</source>
        <translation>Extrair arquivo em uma pasta</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="223"/>
        <source>Add Directory</source>
        <translation>Adicionar pasta</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="226"/>
        <source>Add directory to archive</source>
        <translation>Adicionar pasta para o arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="231"/>
        <source>Extract Selection</source>
        <translation>Extrair seleção</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="234"/>
        <source>Extract Selected Items</source>
        <translation>Extrair itens selecionados</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>USB Image</source>
        <translation>Imagem USB</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="242"/>
        <source>Copy an IMG to a USB device (may require admin permission)</source>
        <translation>Copiar IMG para um USB (pode exigir permissão de administrador)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="28"/>
        <source>Archive Manager</source>
        <translation>Gerenciador de arquivos</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="29"/>
        <source>Admin Mode</source>
        <translation>Modo administrador</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="55"/>
        <source>CTRL+N</source>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="56"/>
        <source>CTRL+O</source>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="57"/>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="58"/>
        <source>CTRL+E</source>
        <translation>CTRL+E</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="69"/>
        <location filename="../MainUI.cpp" line="331"/>
        <source>MimeType</source>
        <translation>MIME</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="69"/>
        <location filename="../MainUI.cpp" line="331"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="94"/>
        <location filename="../MainUI.cpp" line="236"/>
        <source>Opening Archive...</source>
        <translation>Abrindo arquivo...</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="180"/>
        <source>All Types %1</source>
        <translation>Todos tipos %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="181"/>
        <location filename="../MainUI.cpp" line="199"/>
        <source>Uncompressed Archive (*.tar)</source>
        <translation>Arquivo sem compressão (*.tar)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="182"/>
        <location filename="../MainUI.cpp" line="200"/>
        <source>GZip Compressed Archive (*.tar.gz *.tgz)</source>
        <translation>Arquivo comprimido GZip (*.tar.gz *.tgz)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="183"/>
        <location filename="../MainUI.cpp" line="201"/>
        <source>BZip Compressed Archive (*.tar.bz *.tbz)</source>
        <translation>Arquivo comprimido BZip (*.tar.bz *.tbz)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="184"/>
        <location filename="../MainUI.cpp" line="202"/>
        <source>BZip2 Compressed Archive (*.tar.bz2 *.tbz2)</source>
        <translation>Arquivo comprimido BZip2 (*.tar.bz2 *.tbz2)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="185"/>
        <location filename="../MainUI.cpp" line="204"/>
        <source>LMZA Compressed Archive (*.tar.lzma *.tlz)</source>
        <translation>Arquivo comprimido LMZA (*.tar.lzma *.tlz)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="186"/>
        <location filename="../MainUI.cpp" line="203"/>
        <source>XZ Compressed Archive (*.tar.xz *.txz)</source>
        <translation>Arquivo comprimido XZ (*.tar.xz *.txz)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="187"/>
        <location filename="../MainUI.cpp" line="205"/>
        <source>CPIO Archive (*.cpio)</source>
        <translation>Arquivo CPIO (*.cpio)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="188"/>
        <location filename="../MainUI.cpp" line="206"/>
        <source>PAX Archive (*.pax)</source>
        <translation>Arquivo PAX (*.pax)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="189"/>
        <location filename="../MainUI.cpp" line="207"/>
        <source>AR Archive (*.ar)</source>
        <translation>Arquivo AR (*.ar)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="190"/>
        <location filename="../MainUI.cpp" line="208"/>
        <source>SHAR Archive (*.shar)</source>
        <translation>Arquivo SHAR (*.shar)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="191"/>
        <location filename="../MainUI.cpp" line="209"/>
        <source>Zip Archive (*.zip)</source>
        <translation>Arquivo Zip (*.zip)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="192"/>
        <location filename="../MainUI.cpp" line="210"/>
        <source>7-Zip Archive (*.7z)</source>
        <translation>Arquivo 7-Zip (*.7z)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="198"/>
        <source>All Known Types %1</source>
        <translation>Todos os tipos conhecidos %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="211"/>
        <source>READ-ONLY: ISO image (*.iso *.img)</source>
        <translation>SOMENTE LEITURA: imagem ISO (*.iso *.img)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="212"/>
        <source>READ-ONLY: XAR archive (*.xar)</source>
        <translation>SOMENTE LEITURA: arquivo XAR (*.xar)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="213"/>
        <source>READ-ONLY: Java archive (*.jar)</source>
        <translation>SOMENTE LEITURA: arquivo Java (*.jar)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="214"/>
        <source>READ-ONLY: RedHat Package (*.rpm)</source>
        <translation>SOMENTE LEITURA: Pacote RedHat (*.rpm)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="215"/>
        <source>Show All Files (*)</source>
        <translation>Mostrar todos arquivo (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="223"/>
        <source>Create Archive</source>
        <translation>Criar arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="226"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="226"/>
        <source>Could not overwrite file:</source>
        <translation>Não foi possível substituir o arquivo:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="234"/>
        <source>Open Archive</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="242"/>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Add to Archive</source>
        <translation>Adicionar arquivo</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="244"/>
        <location filename="../MainUI.cpp" line="251"/>
        <location filename="../MainUI.cpp" line="300"/>
        <source>Adding Items...</source>
        <translation>Adicionando itens...</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="262"/>
        <source>Removing Items...</source>
        <translation>Removendo itens...</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="267"/>
        <location filename="../MainUI.cpp" line="311"/>
        <source>Extract Into Directory</source>
        <translation>Extrair em uma pasta</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="269"/>
        <location filename="../MainUI.cpp" line="287"/>
        <location filename="../MainUI.cpp" line="294"/>
        <location filename="../MainUI.cpp" line="313"/>
        <location filename="../MainUI.cpp" line="325"/>
        <source>Extracting...</source>
        <translation>Extraindo...</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="345"/>
        <source>Link To: %1</source>
        <translation>Link para: %1</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="618"/>
        <source>Multimedia</source>
        <translation>Multimídia</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="619"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="620"/>
        <source>Education</source>
        <translation>Educação</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="621"/>
        <source>Games</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="622"/>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="623"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="624"/>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="625"/>
        <source>Science</source>
        <translation>Ciência</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="626"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="627"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="628"/>
        <source>Utility</source>
        <translation>Utilitários</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="629"/>
        <source>Wine</source>
        <translation>Wine</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="630"/>
        <source>Unsorted</source>
        <translation>Não classificado</translation>
    </message>
</context>
<context>
    <name>imgDialog</name>
    <message>
        <location filename="../imgDialog.ui" line="14"/>
        <source>Burn IMG to device</source>
        <translation>Gravar IMG no dispositivo</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="29"/>
        <source>IMG File</source>
        <translation>Arquivo IMG</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="54"/>
        <source>Block Size</source>
        <translation>Tamanho do bloco</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="84"/>
        <source>USB Device</source>
        <translation>Dispositivo USB</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="96"/>
        <source>Refresh Device List</source>
        <translation>Atualizar lista de dispositivos</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="108"/>
        <source>Wipe all extra space on device (conv = sync)</source>
        <translation>Limpar todo o espaço extra no dispositivo (conv = sync)</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="132"/>
        <source>Burning to USB:</source>
        <translation>Gravar para USB:</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="166"/>
        <source>Time Elapsed:</source>
        <translation>Tempo decorrido:</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="222"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../imgDialog.ui" line="229"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="22"/>
        <source>Admin Mode</source>
        <translation>Modo administrador</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="36"/>
        <source>Kilobyte(s)</source>
        <translation>Kilobyte(s)</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="37"/>
        <source>Megabyte(s)</source>
        <translation>Megabyte(s)</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="38"/>
        <source>Gigabyte(s)</source>
        <translation>Gigabyte(s)</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="110"/>
        <source>Cancel Image Burn?</source>
        <translation>Cancelar gravação da imagem?</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="21"/>
        <source>Burn Disk Image to Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="110"/>
        <source>Warning: This will leave the USB device in an inconsistent state</source>
        <translation>Aviso: isso deixará o dispositivo USB em um estado inconsistente</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="110"/>
        <source>Do you wish to stop the current disk image burn process?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="170"/>
        <source>Administrator Permissions Needed</source>
        <translation>Permissões de administrador necessárias</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="170"/>
        <source>This operation requires administrator priviledges.</source>
        <translation>Esta operação requer privilégios de administrador.</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="170"/>
        <source>Would you like to enable these priviledges?</source>
        <translation>Gostaria de habilitar esses privilégios?</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="175"/>
        <source>ERROR</source>
        <translation>ERRO</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="175"/>
        <source>The process could not be completed:</source>
        <translation>O processo não pôde ser concluído:</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="178"/>
        <source>SUCCESS</source>
        <translation>ÊXITO</translation>
    </message>
    <message>
        <location filename="../imgDialog.cpp" line="178"/>
        <source>The image was successfully burned to the device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
